@@ -12,12 +12,7 @@ import openai.types.chat as openai_chat_types
 
 from maitai._config import config
 from maitai._evaluator import Evaluator
-from maitai._inference import (
-    Inference,
-    InferenceException,
-    InferenceWarning,
-    MaitaiConnectionError,
-)
+from maitai._inference import Inference
 from maitai._types import (
     Body,
     EvaluateCallback,
@@ -35,6 +30,11 @@ from maitai._utils import (
     required_args,
     type_to_response_format_param,
 )
+from maitai.exceptions import (
+    InferenceException,
+    InferenceWarning,
+    MaitaiConnectionError,
+)
 from maitai.models.chat import (
     AzureParams,
     ChatCompletionParams,
@@ -43,6 +43,7 @@ from maitai.models.chat import (
 )
 from maitai.models.config import InferenceLocations
 from maitai.models.inference import InferenceStreamResponse
+from maitai.models.key import Key
 from maitai.models.metric import RequestTimingMetric
 from maitai.tools import Tools
 
@@ -77,7 +78,7 @@ class Maitai:
         if not maitai_api_key:
             maitai_api_key = os.environ.get("MAITAI_API_KEY")
         if maitai_api_key:
-            config.initialize(maitai_api_key, use_async=False)
+            config.initialize(maitai_api_key)
         else:
             raise ValueError(
                 "MAITAI_API_KEY has not been set. Either set via environment variable or pass it directly into the client."
@@ -87,17 +88,47 @@ class Maitai:
                 "api_key is deprecated. Use provider specific keys instead. Supported variables: openai_api_key, groq_api_key, anthropic_api_key, cerebras_api_key, azure_api_key, sambanova_api_key"
             )
         if openai_api_key:
-            config.auth_keys.openai_api_key.key_value = openai_api_key
+            if not config.auth_keys.openai_api_key:
+                config.auth_keys.openai_api_key = Key(
+                    key_value=openai_api_key,
+                )
+            else:
+                config.auth_keys.openai_api_key.key_value = openai_api_key
         if groq_api_key:
-            config.auth_keys.groq_api_key.key_value = groq_api_key
+            if not config.auth_keys.groq_api_key:
+                config.auth_keys.groq_api_key = Key(
+                    key_value=groq_api_key,
+                )
+            else:
+                config.auth_keys.groq_api_key.key_value = groq_api_key
         if anthropic_api_key:
-            config.auth_keys.anthropic_api_key.key_value = anthropic_api_key
+            if not config.auth_keys.anthropic_api_key:
+                config.auth_keys.anthropic_api_key = Key(
+                    key_value=anthropic_api_key,
+                )
+            else:
+                config.auth_keys.anthropic_api_key.key_value = anthropic_api_key
         if cerebras_api_key:
-            config.auth_keys.cerebras_api_key.key_value = cerebras_api_key
+            if not config.auth_keys.cerebras_api_key:
+                config.auth_keys.cerebras_api_key = Key(
+                    key_value=cerebras_api_key,
+                )
+            else:
+                config.auth_keys.cerebras_api_key.key_value = cerebras_api_key
         if azure_api_key:
-            config.auth_keys.azure_api_key.key_value = azure_api_key
+            if not config.auth_keys.azure_api_key:
+                config.auth_keys.azure_api_key = Key(
+                    key_value=azure_api_key,
+                )
+            else:
+                config.auth_keys.azure_api_key.key_value = azure_api_key
         if sambanova_api_key:
-            config.auth_keys.sambanova_api_key.key_value = sambanova_api_key
+            if not config.auth_keys.sambanova_api_key:
+                config.auth_keys.sambanova_api_key = Key(
+                    key_value=sambanova_api_key,
+                )
+            else:
+                config.auth_keys.sambanova_api_key.key_value = sambanova_api_key
         self._client = None
         azure_params = None
         if azure_api_key:
@@ -209,6 +240,7 @@ class Completions:
         max_completion_tokens: Union[Optional[int], openai.NotGiven] = openai.NOT_GIVEN,
         n: Union[Optional[int], openai.NotGiven] = openai.NOT_GIVEN,
         presence_penalty: Union[Optional[float], openai.NotGiven] = openai.NOT_GIVEN,
+        reasoning_effort: Optional[str] = openai.NOT_GIVEN,
         response_format: Union[
             openai_chat_types.completion_create_params.ResponseFormat, openai.NotGiven
         ] = openai.NOT_GIVEN,
@@ -348,6 +380,7 @@ class Completions:
             user=user,
             parallel_tool_calls=parallel_tool_calls,
             extra_headers=extra_headers,
+            reasoning_effort=reasoning_effort,
         )
         if server_side_inference:
             response_timeout = None
@@ -453,6 +486,7 @@ class Completions:
                 max_tokens=max_tokens,
                 n=n,
                 presence_penalty=presence_penalty,
+                reasoning_effort=reasoning_effort,
                 response_format=response_format,
                 seed=seed,
                 stop=stop,
